==> PyAlgoTrade-0.13.tar.gz: PyAlgoTrade-0.13/pyalgotrade/barfeed/yahoofeed.py <==
# PyAlgoTrade
# 
# Copyright 2012 Gabriel Martin Becedillas Ruiz
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#   http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
.. moduleauthor:: Gabriel Martin Becedillas Ruiz <gabriel.becedillas@gmail.com>
"""

from pyalgotrade import barfeed
from pyalgotrade.barfeed import csvfeed
from pyalgotrade.utils import dt
from pyalgotrade import bar
from pyalgotrade import dataseries

import types
import datetime

######################################################################
## Yahoo Finance CSV parser
# Each bar must be on its own line and fields must be separated by comma (,).
#
# Bars Format:
# Date,Open,High,Low,Close,Volume,Adj Close
#
# The csv Date column must have the following format: YYYY-MM-DD

def parse_date(date):
	# Sample: 2005-12-30
	# This custom parsing works faster than:
	# datetime.datetime.strptime(date, "%Y-%m-%d")
	year = int(date[0:4])
	month = int(date[5:7])
	day = int(date[8:10])
	ret = datetime.datetime(year, month, day)
	return ret

class RowParser(csvfeed.RowParser):
	def __init__(self, dailyBarTime, timezone = None):
		self.__dailyBarTime = dailyBarTime
		self.__timezone = timezone

	def __parseDate(self, dateString):
		ret = parse_date(dateString)
		# Time on Yahoo! Finance CSV files is empty. If told to set one, do it.
		if self.__dailyBarTime != None:
			ret = datetime.datetime.combine(ret, self.__dailyBarTime)
		# Localize the datetime if a timezone was given.
		if self.__timezone:
			ret = dt.localize(ret, self.__timezone)
		return ret

	def getFieldNames(self):
		# It is expected for the first row to have the field names.
		return None

	def getDelimiter(self):
		return ","

	def parseBar(self, csvRowDict):
		dateTime = self.__parseDate(csvRowDict["Date"])
		close = float(csvRowDict["Close"])
		open_ = float(csvRowDict["Open"])
		high = float(csvRowDict["High"])
		low = float(csvRowDict["Low"])
		volume = float(csvRowDict["Volume"])
		adjClose = float(csvRowDict["Adj Close"])
		return bar.BasicBar(dateTime, open_, high, low, close, volume, adjClose)

class Feed(csvfeed.BarFeed):
	"""A :class:`pyalgotrade.barfeed.csvfeed.BarFeed` that loads bars from CSV files downloaded from Yahoo! Finance.

	:param timezone: The default timezone to use to localize bars. Check :mod:`pyalgotrade.marketsession`.
	:type timezone: A pytz timezone.
	:param maxLen: The maximum number of values that the :class:`pyalgotrade.dataseries.bards.BarDataSeries` will hold.
		If not None, it must be greater than 0.
		Once a bounded length is full, when new items are added, a corresponding number of items are discarded from the opposite end.
	:type maxLen: int.

	.. note::
		Yahoo! Finance csv files lack timezone information.
		When working with multiple instruments:

			* If all the instruments loaded are in the same timezone, then the timezone parameter may not be specified.
			* If any of the instruments loaded are from different timezones, then the timezone parameter must be set.
	"""

	def __init__(self, timezone = None, maxLen=dataseries.DEFAULT_MAX_LEN):
		if type(timezone) == types.IntType:
			raise Exception("timezone as an int parameter is not supported anymore. Please use a pytz timezone instead.")

		csvfeed.BarFeed.__init__(self, barfeed.Frequency.DAY, maxLen)
		self.__timezone = timezone

	def barsHaveAdjClose(self):
		return True

	def addBarsFromCSV(self, instrument, path, timezone = None):
		"""Loads bars for a given instrument from a CSV formatted file.
		The instrument gets registered in the bar feed.
		
		:param instrument: Instrument identifier.
		:type instrument: string.
		:param path: The path to the CSV file.
		:type path: string.
		:param timezone: The timezone to use to localize bars. Check :mod:`pyalgotrade.marketsession`.
		:type timezone: A pytz timezone.
		"""

		if type(timezone) == types.IntType:
			raise Exception("timezone as an int parameter is not supported anymore. Please use a pytz timezone instead.")

		if timezone is None:
			timezone = self.__timezone
		rowParser = RowParser(self.getDailyBarTime(), timezone)
		csvfeed.BarFeed.addBarsFromCSV(self, instrument, path, rowParser)

==> PyAlgoTrade-0.14.tar.gz: PyAlgoTrade-0.14/pyalgotrade/barfeed/yahoofeed.py <==
# PyAlgoTrade
# 
# Copyright 2012 Gabriel Martin Becedillas Ruiz
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#   http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
.. moduleauthor:: Gabriel Martin Becedillas Ruiz <gabriel.becedillas@gmail.com>
"""

from pyalgotrade import barfeed
from pyalgotrade.barfeed import csvfeed
from pyalgotrade.utils import dt
from pyalgotrade import bar
from pyalgotrade import dataseries

import types
import datetime

######################################################################
## Yahoo Finance CSV parser
# Each bar must be on its own line and fields must be separated by comma (,).
#
# Bars Format:
# Date,Open,High,Low,Close,Volume,Adj Close
#
# The csv Date column must have the following format: YYYY-MM-DD

def parse_date(date):
	# Sample: 2005-12-30
	# This custom parsing works faster than:
	# datetime.datetime.strptime(date, "%Y-%m-%d")
	year = int(date[0:4])
	month = int(date[5:7])
	day = int(date[8:10])
	ret = datetime.datetime(year, month, day)
	return ret

class RowParser(csvfeed.RowParser):
	def __init__(self, dailyBarTime, timezone=None, sanitize=False):
		self.__dailyBarTime = dailyBarTime
		self.__timezone = timezone
		self.__sanitize = sanitize

	def __parseDate(self, dateString):
		ret = parse_date(dateString)
		# Time on Yahoo! Finance CSV files is empty. If told to set one, do it.
		if self.__dailyBarTime != None:
			ret = datetime.datetime.combine(ret, self.__dailyBarTime)
		# Localize the datetime if a timezone was given.
		if self.__timezone:
			ret = dt.localize(ret, self.__timezone)
		return ret

	def getFieldNames(self):
		# It is expected for the first row to have the field names.
		return None

	def getDelimiter(self):
		return ","

	def parseBar(self, csvRowDict):
		dateTime = self.__parseDate(csvRowDict["Date"])
		close = float(csvRowDict["Close"])
		open_ = float(csvRowDict["Open"])
		high = float(csvRowDict["High"])
		low = float(csvRowDict["Low"])
		volume = float(csvRowDict["Volume"])
		adjClose = float(csvRowDict["Adj Close"])

		if self.__sanitize:
			if low > open_:
				low = open_
			if low > close:
				low = close
			if high < open_:
				high = open_
			if high < close:
				high = close

		return bar.BasicBar(dateTime, open_, high, low, close, volume, adjClose)

class Feed(csvfeed.BarFeed):
	"""A :class:`pyalgotrade.barfeed.csvfeed.BarFeed` that loads bars from CSV files downloaded from Yahoo! Finance.

	:param timezone: The default timezone to use to localize bars. Check :mod:`pyalgotrade.marketsession`.
	:type timezone: A pytz timezone.
	:param maxLen: The maximum number of values that the :class:`pyalgotrade.dataseries.bards.BarDataSeries` will hold.
		If not None, it must be greater than 0.
		Once a bounded length is full, when new items are added, a corresponding number of items are discarded from the opposite end.
	:type maxLen: int.

	.. note::
		Yahoo! Finance csv files lack timezone information.
		When working with multiple instruments:

			* If all the instruments loaded are in the same timezone, then the timezone parameter may not be specified.
			* If any of the instruments loaded are from different timezones, then the timezone parameter must be set.
	"""

	def __init__(self, timezone = None, maxLen=dataseries.DEFAULT_MAX_LEN):
		if type(timezone) == types.IntType:
			raise Exception("timezone as an int parameter is not supported anymore. Please use a pytz timezone instead.")

		csvfeed.BarFeed.__init__(self, barfeed.Frequency.DAY, maxLen)
		self.__timezone = timezone
		self.__sanitizeBars = False

	def sanitizeBars(self, sanitize):
		self.__sanitizeBars = sanitize

	def barsHaveAdjClose(self):
		return True

	def addBarsFromCSV(self, instrument, path, timezone = None):
		"""Loads bars for a given instrument from a CSV formatted file.
		The instrument gets registered in the bar feed.
		
		:param instrument: Instrument identifier.
		:type instrument: string.
		:param path: The path to the CSV file.
		:type path: string.
		:param timezone: The timezone to use to localize bars. Check :mod:`pyalgotrade.marketsession`.
		:type timezone: A pytz timezone.
		"""

		if type(timezone) == types.IntType:
			raise Exception("timezone as an int parameter is not supported anymore. Please use a pytz timezone instead.")

		if timezone is None:
			timezone = self.__timezone
		rowParser = RowParser(self.getDailyBarTime(), timezone, self.__sanitizeBars)
		csvfeed.BarFeed.addBarsFromCSV(self, instrument, path, rowParser)
